@@ -1,8 +1,9 @@
-'AS lookup tool'
+'Multi-service IP-AS lookup tool'
 
-import logging
 import pkg_resources
 
+from .lookup import get_as_data  # noqa: F401
+
 
 __application_name__ = __name__
 __version__ = pkg_resources.get_distribution(__application_name__).version
